@@ -21,21 +21,21 @@
 using namespace UserMetricsCommon;
 
 QString DBusPaths::serviceName() {
-	return "com.canonical.UserMetrics";
+	return "com.lomiri.UserMetrics";
 }
 
 QString DBusPaths::userMetrics() {
-	return "/com/canonical/UserMetrics";
+	return "/com/lomiri/UserMetrics";
 }
 
 QString DBusPaths::userData(int id) {
-	return QString("/com/canonical/UserMetrics/UserData/%1").arg(id);
+	return QString("/com/lomiri/UserMetrics/UserData/%1").arg(id);
 }
 
 QString DBusPaths::dataSource(int id) {
-	return QString("/com/canonical/UserMetrics/DataSource/%1").arg(id);
+	return QString("/com/lomiri/UserMetrics/DataSource/%1").arg(id);
 }
 
 QString DBusPaths::dataSet(int id) {
-	return QString("/com/canonical/UserMetrics/DataSet/%1").arg(id);
+	return QString("/com/lomiri/UserMetrics/DataSet/%1").arg(id);
 }
