@@ -21,7 +21,7 @@
 using namespace UserMetricsOutput;
 
 SyncedDataSet::SyncedDataSet(
-		QSharedPointer<com::canonical::usermetrics::DataSet> interface,
+		QSharedPointer<com::lomiri::usermetrics::DataSet> interface,
 		DataSourcePtr dataSource, QObject *parent) :
 		DataSet(dataSource, parent), m_interface(interface) {
 
