@@ -27,10 +27,9 @@ using namespace QtDBusTest;
 DBusTest::DBusTest() {
 	qputenv("USERMETRICS_NO_AUTH", "1");
 	qputenv("USERMETRICS_NO_COLOR_SETTINGS", "1");
-	qputenv("USERMETRICS_COLOR_SCHEMA_BASEDIR", USERMETRICS_TEST_COLOR_BASEDIR);
-	qputenv("USERMETRICS_COLOR_THEME_BASEDIR", USERMETRICS_TEST_COLOR_BASEDIR);
+	qputenv("XDG_DATA_DIRS", DATA_DIR);
 	DBusServicePtr userMetricsService(
-			new QProcessDBusService("com.canonical.UserMetrics",
+			new QProcessDBusService("com.lomiri.UserMetrics",
 					QDBusConnection::SystemBus, USERMETRICSSERVICE_BINARY,
 					QStringList() << ":memory:"));
 	dbus.registerService(userMetricsService);
