@@ -65,7 +65,7 @@ protected:
 };
 
 TEST_F(TestSyncedUserMetricsStore, LoadsDataSourcesAtStartup) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath dataSourcePath1(
@@ -107,7 +107,7 @@ TEST_F(TestSyncedUserMetricsStore, LoadsDataSourcesAtStartup) {
 }
 
 TEST_F(TestSyncedUserMetricsStore, SyncsNewDataSources) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath dataSourcePath1(
@@ -167,7 +167,7 @@ TEST_F(TestSyncedUserMetricsStore, SyncsNewDataSources) {
 }
 
 TEST_F(TestSyncedUserMetricsStore, LoadsUserDataAtStartup) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath userDataPath(
@@ -197,7 +197,7 @@ TEST_F(TestSyncedUserMetricsStore, LoadsUserDataAtStartup) {
 }
 
 TEST_F(TestSyncedUserMetricsStore, SyncsNewUserData) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath userDataPath(
@@ -243,7 +243,7 @@ TEST_F(TestSyncedUserMetricsStore, SyncsNewUserData) {
 }
 
 TEST_F(TestSyncedUserMetricsStore, LoadsDataSetsAtStartup) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath twitterPath(
@@ -256,7 +256,7 @@ TEST_F(TestSyncedUserMetricsStore, LoadsDataSetsAtStartup) {
 			userMetricsInterface.createUserData("username"));
 	ASSERT_EQ(DBusPaths::userData(1), userDataPath.path());
 
-	com::canonical::usermetrics::UserData userDataInterface(
+	com::lomiri::usermetrics::UserData userDataInterface(
 			DBusPaths::serviceName(), DBusPaths::userData(1),
 			systemConnection());
 	QDBusObjectPath twitterDataPath(userDataInterface.createDataSet("twitter"));
@@ -265,7 +265,7 @@ TEST_F(TestSyncedUserMetricsStore, LoadsDataSetsAtStartup) {
 	QVariantList data( { 100.0, 50.0, "", -50.0, -100.0 });
 	QVariantList expected( { 1.0, 0.75, QVariant(), 0.25, 0.0 });
 
-	com::canonical::usermetrics::DataSet dataSetInterface(
+	com::lomiri::usermetrics::DataSet dataSetInterface(
 			DBusPaths::serviceName(), DBusPaths::dataSet(1),
 			systemConnection());
 	dataSetInterface.update(data);
@@ -289,7 +289,7 @@ TEST_F(TestSyncedUserMetricsStore, LoadsDataSetsAtStartup) {
 }
 
 TEST_F(TestSyncedUserMetricsStore, SyncsNewDataSets) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath twitterPath(
@@ -308,7 +308,7 @@ TEST_F(TestSyncedUserMetricsStore, SyncsNewDataSets) {
 			userMetricsInterface.createUserData("username"));
 	ASSERT_EQ(DBusPaths::userData(1), userDataPath.path());
 
-	com::canonical::usermetrics::UserData userDataInterface(
+	com::lomiri::usermetrics::UserData userDataInterface(
 			DBusPaths::serviceName(), DBusPaths::userData(1),
 			systemConnection());
 
@@ -362,7 +362,7 @@ TEST_F(TestSyncedUserMetricsStore, SyncsNewDataSets) {
 }
 
 TEST_F(TestSyncedUserMetricsStore, MergesSystemDataAtStartup) {
-	com::canonical::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
+	com::lomiri::UserMetrics userMetricsInterface(DBusPaths::serviceName(),
 			DBusPaths::userMetrics(), systemConnection());
 
 	QDBusObjectPath twitterPath(
@@ -384,7 +384,7 @@ TEST_F(TestSyncedUserMetricsStore, MergesSystemDataAtStartup) {
 	QDBusObjectPath systemDataPath(userMetricsInterface.createUserData(""));
 	ASSERT_EQ(DBusPaths::userData(2), systemDataPath.path());
 
-	com::canonical::usermetrics::UserData userDataInterface(
+	com::lomiri::usermetrics::UserData userDataInterface(
 			DBusPaths::serviceName(), DBusPaths::userData(1),
 			systemConnection());
 	QDBusObjectPath twitterDataPath(userDataInterface.createDataSet("twitter"));
@@ -393,12 +393,12 @@ TEST_F(TestSyncedUserMetricsStore, MergesSystemDataAtStartup) {
 	QVariantList twitterData( { 100.0, 50.0, "", -50.0, -100.0 });
 	QVariantList twitterExpected( { 1.0, 0.75, QVariant(), 0.25, 0.0 });
 
-	com::canonical::usermetrics::DataSet twitterDataSetInterface(
+	com::lomiri::usermetrics::DataSet twitterDataSetInterface(
 			DBusPaths::serviceName(), DBusPaths::dataSet(1),
 			systemConnection());
 	twitterDataSetInterface.update(twitterData);
 
-	com::canonical::usermetrics::UserData systemDataInterface(
+	com::lomiri::usermetrics::UserData systemDataInterface(
 			DBusPaths::serviceName(), DBusPaths::userData(2),
 			systemConnection());
 	QDBusObjectPath batteryDataPath(
@@ -408,7 +408,7 @@ TEST_F(TestSyncedUserMetricsStore, MergesSystemDataAtStartup) {
 	QVariantList batteryData( { -100.0, -50.0, "", 50.0, 100.0 });
 	QVariantList batteryExpected( { 0.0, 0.25, QVariant(), 0.75, 1.0 });
 
-	com::canonical::usermetrics::DataSet batteryDataSetInterface(
+	com::lomiri::usermetrics::DataSet batteryDataSetInterface(
 			DBusPaths::serviceName(), DBusPaths::dataSet(2),
 			systemConnection());
 	batteryDataSetInterface.update(batteryData);
